import { ImageSource } from '@nativescript/core';
import type { HttpsRequestOptions } from './request';
export * from './request';
/**
 * Downloads the content from the specified URL as a string.
 * @param arg either The URL to request from or HttpsRequestOptions options.
 */
export declare function getString(arg: string | HttpsRequestOptions): Promise<string>;
/**
 * Downloads the content from the specified URL as a string and returns its JSON.parse representation.
 * @param arg either The URL to request from or HttpsRequestOptions options.
 */
export declare function getJSON<T>(arg: string | HttpsRequestOptions): Promise<T>;
/**
 * Downloads the content from the specified URL and attempts to decode it as an image.
 * @param arg either The URL to request from or HttpsRequestOptions options.
 */
export declare function getImage(arg: string | HttpsRequestOptions): Promise<ImageSource>;
/**
 * Downloads the content from the specified URL and attempts to save it as file.
 * @param arg either The URL to request from or HttpsRequestOptions options.
 * @param destinationFilePath Optional. The downloaded file path.
 */
export declare function getFile(arg: string | HttpsRequestOptions, destinationFilePath?: string): Promise<any>;
/**
 * Downloads the content from the specified URL as binary and returns an ArrayBuffer.
 * @param arg either The URL to request from or HttpsRequestOptions options.
 */
export declare function getBinary(arg: string | HttpsRequestOptions): Promise<ArrayBuffer>;
